# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: autopilot.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61utopilot.proto\x12\x1amagothy.protobuf.autopilot\x1a\x1fgoogle/protobuf/timestamp.proto\"(\n\x05\x45rror\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"7\n\x08Position\x12\x14\n\x0clatitude_deg\x18\x01 \x01(\x01\x12\x15\n\rlongitude_deg\x18\x02 \x01(\x01\":\n\x0b\x41ngularRate\x12\r\n\x05x_dps\x18\x01 \x01(\x01\x12\r\n\x05y_dps\x18\x02 \x01(\x01\x12\r\n\x05z_dps\x18\x03 \x01(\x01\">\n\x0c\x41\x63\x63\x65leration\x12\x0e\n\x06x_mps2\x18\x01 \x01(\x01\x12\x0e\n\x06y_mps2\x18\x02 \x01(\x01\x12\x0e\n\x06z_mps2\x18\x03 \x01(\x01\"B\n\rMagneticField\x12\x0f\n\x07x_gauss\x18\x01 \x01(\x01\x12\x0f\n\x07y_gauss\x18\x02 \x01(\x01\x12\x0f\n\x07z_gauss\x18\x03 \x01(\x01\"A\n\x05\x45uler\x12\x10\n\x08roll_deg\x18\x01 \x01(\x01\x12\x11\n\tpitch_deg\x18\x02 \x01(\x01\x12\x13\n\x0bheading_deg\x18\x03 \x01(\x01\";\n\x0c\x42odyVelocity\x12\r\n\x05x_mps\x18\x01 \x01(\x01\x12\r\n\x05y_mps\x18\x02 \x01(\x01\x12\r\n\x05z_mps\x18\x03 \x01(\x01\"I\n\x10InertialVelocity\x12\x11\n\tnorth_mps\x18\x01 \x01(\x01\x12\x10\n\x08\x65\x61st_mps\x18\x02 \x01(\x01\x12\x10\n\x08\x64own_mps\x18\x03 \x01(\x01\"8\n\x0cWaterCurrent\x12\x11\n\tspeed_mps\x18\x01 \x01(\x01\x12\x15\n\rdirection_deg\x18\x02 \x01(\x01\"R\n\tFuelGauge\x12\x11\n\tvoltage_V\x18\x01 \x01(\x01\x12\x11\n\tcurrent_A\x18\x02 \x01(\x01\x12\x1f\n\x17state_of_charge_percent\x18\x03 \x01(\x01\"\xad\x17\n\x0bVehicleData\x12;\n\x08position\x18\x01 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x00\x88\x01\x01\x12K\n\x0fposition_source\x18\x02 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17position_ttag_ns_steady\x18\x03 \x01(\x04\x12@\n\x10position_error_m\x18( \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x01\x88\x01\x01\x12Q\n\x15position_error_source\x18) \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1dposition_error_ttag_ns_steady\x18* \x01(\x04\x12\x38\n\x08\x61ttitude\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x02\x88\x01\x01\x12K\n\x0f\x61ttitude_source\x18\x05 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17\x61ttitude_ttag_ns_steady\x18\x06 \x01(\x04\x12\x42\n\x12\x61ttitude_error_deg\x18+ \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x03\x88\x01\x01\x12Q\n\x15\x61ttitude_error_source\x18, \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1d\x61ttitude_error_ttag_ns_steady\x18- \x01(\x04\x12\x42\n\x0c\x61ngular_rate\x18\x07 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x04\x88\x01\x01\x12O\n\x13\x61ngular_rate_source\x18\x08 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12#\n\x1b\x61ngular_rate_ttag_ns_steady\x18\t \x01(\x04\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x05\x88\x01\x01\x12O\n\x13\x61\x63\x63\x65leration_source\x18\x0b \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12#\n\x1b\x61\x63\x63\x65leration_ttag_ns_steady\x18\x0c \x01(\x04\x12\x46\n\x0emagnetic_field\x18\r \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x06\x88\x01\x01\x12Q\n\x15magnetic_field_source\x18\x0e \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12%\n\x1dmagnetic_field_ttag_ns_steady\x18\x0f \x01(\x04\x12\x14\n\x07\x64\x65pth_m\x18\x10 \x01(\x01H\x07\x88\x01\x01\x12H\n\x0c\x64\x65pth_source\x18\x11 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1c\n\x14\x64\x65pth_ttag_ns_steady\x18\x12 \x01(\x04\x12\x17\n\naltitude_m\x18\x13 \x01(\x01H\x08\x88\x01\x01\x12K\n\x0f\x61ltitude_source\x18\x14 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1f\n\x17\x61ltitude_ttag_ns_steady\x18\x15 \x01(\x04\x12\x16\n\tspeed_mps\x18\x16 \x01(\x01H\t\x88\x01\x01\x12H\n\x0cspeed_source\x18\x17 \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1c\n\x14speed_ttag_ns_steady\x18\x18 \x01(\x04\x12\x17\n\ncourse_deg\x18\x19 \x01(\x01H\n\x88\x01\x01\x12I\n\rcourse_source\x18\x1a \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12\x1d\n\x15\x63ourse_ttag_ns_steady\x18\x1b \x01(\x04\x12\x44\n\rbody_velocity\x18\x1c \x01(\x0b\x32(.magothy.protobuf.autopilot.BodyVelocityH\x0b\x88\x01\x01\x12P\n\x14\x62ody_velocity_source\x18\x1d \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12$\n\x1c\x62ody_velocity_ttag_ns_steady\x18\x1e \x01(\x04\x12\x44\n\rwater_current\x18\x1f \x01(\x0b\x32(.magothy.protobuf.autopilot.WaterCurrentH\x0c\x88\x01\x01\x12P\n\x14water_current_source\x18  \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12$\n\x1cwater_current_ttag_ns_steady\x18! \x01(\x04\x12%\n\x18water_relative_speed_mps\x18\" \x01(\x01H\r\x88\x01\x01\x12W\n\x1bwater_relative_speed_source\x18# \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12+\n#water_relative_speed_ttag_ns_steady\x18$ \x01(\x04\x12>\n\nfuel_gauge\x18% \x01(\x0b\x32%.magothy.protobuf.autopilot.FuelGaugeH\x0e\x88\x01\x01\x12M\n\x11\x66uel_gauge_source\x18& \x01(\x0e\x32\x32.magothy.protobuf.autopilot.VehicleData.DataSource\x12!\n\x19\x66uel_gauge_ttag_ns_steady\x18\' \x01(\x04\"\xb3\x01\n\nDataSource\x12\r\n\tDS_NODATA\x10\x00\x12\n\n\x06\x44S_IMU\x10\x01\x12\x0b\n\x07\x44S_AHRS\x10\x02\x12\n\n\x06\x44S_GPS\x10\x03\x12\x0c\n\x08\x44S_DEPTH\x10\x04\x12\x0f\n\x0b\x44S_ALTITUDE\x10\x05\x12\x0c\n\x08\x44S_SPEED\x10\x06\x12\x11\n\rDS_ESTIMATION\x10\x07\x12\x12\n\x0e\x44S_COMPUTATION\x10\x08\x12\x11\n\rDS_SIMULATION\x10\t\x12\n\n\x06\x44S_INS\x10\nB\x0b\n\t_positionB\x13\n\x11_position_error_mB\x0b\n\t_attitudeB\x15\n\x13_attitude_error_degB\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x11\n\x0f_magnetic_fieldB\n\n\x08_depth_mB\r\n\x0b_altitude_mB\x0c\n\n_speed_mpsB\r\n\x0b_course_degB\x10\n\x0e_body_velocityB\x10\n\x0e_water_currentB\x1b\n\x19_water_relative_speed_mpsB\r\n\x0b_fuel_gauge\"\x98\x03\n\x06\x41hrsIf\x12\x42\n\x0c\x61ngular_rate\x18\x01 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x00\x88\x01\x01\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x01\x88\x01\x01\x12@\n\x08magfield\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x02\x88\x01\x01\x12\x35\n\x05\x65uler\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x03\x88\x01\x01\x12?\n\x0f\x65uler_error_deg\x18\x07 \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x04\x88\x01\x01\x42\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x0b\n\t_magfieldB\x08\n\x06_eulerB\x12\n\x10_euler_error_deg\"4\n\nAltitudeIf\x12\x17\n\naltitude_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\r\n\x0b_altitude_m\"\x99\x01\n\tBatteryIf\x12\x16\n\tvoltage_V\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x16\n\tcurrent_A\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12$\n\x17state_of_charge_percent\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0c\n\n_voltage_VB\x0c\n\n_current_AB\x1a\n\x18_state_of_charge_percent\"+\n\x07\x44\x65pthIf\x12\x14\n\x07\x64\x65pth_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\n\n\x08_depth_m\"\x1d\n\nEffectorIf\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\x01\"\xf4\x05\n\x05InsIf\x12\x42\n\x0c\x61ngular_rate\x18\x01 \x01(\x0b\x32\'.magothy.protobuf.autopilot.AngularRateH\x00\x88\x01\x01\x12\x43\n\x0c\x61\x63\x63\x65leration\x18\x02 \x01(\x0b\x32(.magothy.protobuf.autopilot.AccelerationH\x01\x88\x01\x01\x12@\n\x08magfield\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.MagneticFieldH\x02\x88\x01\x01\x12\x35\n\x05\x65uler\x18\x04 \x01(\x0b\x32!.magothy.protobuf.autopilot.EulerH\x03\x88\x01\x01\x12?\n\x0f\x65uler_error_deg\x18\x08 \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x04\x88\x01\x01\x12\x44\n\rbody_velocity\x18\x05 \x01(\x0b\x32(.magothy.protobuf.autopilot.BodyVelocityH\x05\x88\x01\x01\x12;\n\x08position\x18\x06 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x06\x88\x01\x01\x12@\n\x10position_error_m\x18\t \x01(\x0b\x32!.magothy.protobuf.autopilot.ErrorH\x07\x88\x01\x01\x12L\n\x11inertial_velocity\x18\x07 \x01(\x0b\x32,.magothy.protobuf.autopilot.InertialVelocityH\x08\x88\x01\x01\x42\x0f\n\r_angular_rateB\x0f\n\r_accelerationB\x0b\n\t_magfieldB\x08\n\x06_eulerB\x12\n\x10_euler_error_degB\x10\n\x0e_body_velocityB\x0b\n\t_positionB\x13\n\x11_position_error_mB\x14\n\x12_inertial_velocity\"\xa3\x08\n\x05GpsIf\x12@\n\x08rmc_data\x18\x01 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.RmcDataH\x00\x88\x01\x01\x12@\n\x08gga_data\x18\x02 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.GgaDataH\x01\x88\x01\x01\x12@\n\x08gst_data\x18\x03 \x01(\x0b\x32).magothy.protobuf.autopilot.GpsIf.GstDataH\x02\x88\x01\x01\x1a\xc7\x01\n\x07RmcData\x12\x19\n\x0clatitude_deg\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rlongitude_deg\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x1c\n\x0fground_speed_kt\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1c\n\x0f\x63ourse_true_deg\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\x0f\n\r_latitude_degB\x10\n\x0e_longitude_degB\x12\n\x10_ground_speed_ktB\x12\n\x10_course_true_deg\x1a\xa0\x03\n\x07GgaData\x12\x19\n\x0clatitude_deg\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rlongitude_deg\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naltitude_m\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x1a\n\rnum_satellite\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12I\n\x0b\x66ix_quality\x18\x05 \x01(\x0e\x32\x34.magothy.protobuf.autopilot.GpsIf.GgaData.FixQuality\"\x99\x01\n\nFixQuality\x12\x0e\n\nFQ_INVALID\x10\x00\x12\n\n\x06\x46Q_GPS\x10\x01\x12\x0b\n\x07\x46Q_DGPS\x10\x02\x12\n\n\x06\x46Q_PPS\x10\x03\x12\x10\n\x0c\x46Q_RTK_FIXED\x10\x04\x12\x10\n\x0c\x46Q_RTK_FLOAT\x10\x05\x12\x10\n\x0c\x46Q_ESTIMATED\x10\x06\x12\r\n\tFQ_MANUAL\x10\x07\x12\x11\n\rFQ_SIMULATION\x10\x08\x42\x0f\n\r_latitude_degB\x10\n\x0e_longitude_degB\r\n\x0b_altitude_mB\x10\n\x0e_num_satellite\x1a\xbf\x01\n\x07GstData\x12!\n\x14std_latitude_error_m\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\"\n\x15std_longitude_error_m\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12!\n\x14std_altitude_error_m\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\x17\n\x15_std_latitude_error_mB\x18\n\x16_std_longitude_error_mB\x17\n\x15_std_altitude_error_mB\x0b\n\t_rmc_dataB\x0b\n\t_gga_dataB\x0b\n\t_gst_data\"\x8c\x05\n\nObstacleIf\x12\n\n\x02id\x18\x01 \x01(\t\x12?\n\x06\x63ircle\x18\x02 \x01(\x0b\x32-.magothy.protobuf.autopilot.ObstacleIf.CircleH\x00\x12\x41\n\x07polygon\x18\x03 \x01(\x0b\x32..magothy.protobuf.autopilot.ObstacleIf.PolygonH\x00\x12\x42\n\tzone_type\x18\x04 \x01(\x0e\x32/.magothy.protobuf.autopilot.ObstacleIf.ZoneType\x12\x15\n\ris_stationary\x18\x05 \x01(\x08\x12\x12\n\nlifespan_s\x18\x06 \x01(\x01\x12\x17\n\ncourse_deg\x18\x07 \x01(\x01H\x01\x88\x01\x01\x12\x16\n\tspeed_mps\x18\x08 \x01(\x01H\x02\x88\x01\x01\x12\x44\n\x11point_of_interest\x18\t \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x03\x88\x01\x01\x1aP\n\x06\x43ircle\x12\x34\n\x06origin\x18\x01 \x01(\x0b\x32$.magothy.protobuf.autopilot.Position\x12\x10\n\x08radius_m\x18\x02 \x01(\x01\x1a\x41\n\x07Polygon\x12\x36\n\x08vertices\x18\x01 \x03(\x0b\x32$.magothy.protobuf.autopilot.Position\"/\n\x08ZoneType\x12\x11\n\rZONE_KEEP_OUT\x10\x00\x12\x10\n\x0cZONE_KEEP_IN\x10\x01\x42\x0f\n\rObstacleOneOfB\r\n\x0b_course_degB\x0c\n\n_speed_mpsB\x14\n\x12_point_of_interest\"\x8f\x01\n\tObstacles\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x39\n\tobstacles\x18\x03 \x03(\x0b\x32&.magothy.protobuf.autopilot.ObstacleIf\"\xfd\x03\n\x04Path\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x32\n\x04path\x18\x03 \x03(\x0b\x32$.magothy.protobuf.autopilot.Position\x12\x39\n\tobstacles\x18\x04 \x03(\x0b\x32&.magothy.protobuf.autopilot.ObstacleIf\x12\x16\n\tspeed_mps\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\x38\n\x05start\x18\x06 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x01\x88\x01\x01\x12<\n\tend_local\x18\x07 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x02\x88\x01\x01\x12=\n\nend_global\x18\x08 \x01(\x0b\x32$.magothy.protobuf.autopilot.PositionH\x03\x88\x01\x01\x12\x39\n\x0bglobal_path\x18\t \x03(\x0b\x32$.magothy.protobuf.autopilot.PositionB\x0c\n\n_speed_mpsB\x08\n\x06_startB\x0c\n\n_end_localB\r\n\x0b_end_global\"\x84\x07\n\x0eVehicleStateIf\x12\x0f\n\x07ttag_ns\x18\x01 \x01(\x04\x12=\n\x0cvehicle_data\x18\x02 \x01(\x0b\x32\'.magothy.protobuf.autopilot.VehicleData\x12=\n\x04mode\x18\x03 \x01(\x0e\x32/.magothy.protobuf.autopilot.VehicleStateIf.Mode\x12K\n\x0chealth_items\x18\x04 \x03(\x0b\x32\x35.magothy.protobuf.autopilot.VehicleStateIf.HealthItem\x12U\n\x0e\x66\x61ult_response\x18\x05 \x01(\x0b\x32\x38.magothy.protobuf.autopilot.VehicleStateIf.FaultResponseH\x00\x88\x01\x01\x1ar\n\nHealthItem\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x11\n\tsensor_id\x18\x03 \x01(\r\x12\x10\n\x08is_valid\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x12\n\nis_healthy\x18\x06 \x01(\x08\x1a\x7f\n\rFaultResponse\x12S\n\rresponse_type\x18\x01 \x01(\x0e\x32<.magothy.protobuf.autopilot.VehicleStateIf.FaultResponseType\x12\x19\n\x11health_item_index\x18\x02 \x01(\r\"\xa2\x01\n\x04Mode\x12\x0e\n\nVS_STANDBY\x10\x00\x12\r\n\tVS_MANUAL\x10\x01\x12\x16\n\x12VS_HEALTHY_MISSION\x10\x02\x12\x18\n\x14VS_UNHEALTHY_MISSION\x10\x03\x12\r\n\tVS_LOITER\x10\x04\x12\x17\n\x13VS_MISSION_PLANNING\x10\x05\x12!\n\x1dVS_UNHEALTHY_MISSION_PLANNING\x10\x06\"\x91\x01\n\x11\x46\x61ultResponseType\x12\r\n\tFR_IGNORE\x10\x00\x12\x0b\n\x07\x46R_HALT\x10\x01\x12\r\n\tFR_LOITER\x10\x02\x12\x0f\n\x0b\x46R_GO_RALLY\x10\x03\x12\x0f\n\x0b\x46R_GO_FIRST\x10\x04\x12\x0e\n\nFR_GO_LAST\x10\x05\x12\x10\n\x0c\x46R_GO_LAUNCH\x10\x06\x12\r\n\tFR_CUSTOM\x10\x07\x42\x11\n\x0f_fault_response\"\x93\x02\n\x15MavlinkMissionItemInt\x12\x15\n\rtarget_system\x18\x01 \x01(\r\x12\x18\n\x10target_component\x18\x02 \x01(\r\x12\x14\n\x0cmission_type\x18\x03 \x01(\r\x12\x0b\n\x03seq\x18\x04 \x01(\r\x12\x0f\n\x07\x63ommand\x18\x05 \x01(\r\x12\r\n\x05\x66rame\x18\x06 \x01(\r\x12\x0f\n\x07\x63urrent\x18\x07 \x01(\x08\x12\x14\n\x0c\x61utocontinue\x18\x08 \x01(\x08\x12\x0e\n\x06param1\x18\t \x01(\x02\x12\x0e\n\x06param2\x18\n \x01(\x02\x12\x0e\n\x06param3\x18\x0b \x01(\x02\x12\x0e\n\x06param4\x18\x0c \x01(\x02\x12\t\n\x01x\x18\r \x01(\x05\x12\t\n\x01y\x18\x0e \x01(\x05\x12\t\n\x01z\x18\x0f \x01(\x02\"\xea\x01\n\x0eMavlinkMission\x12H\n\rmission_items\x18\x01 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemInt\x12\x46\n\x0b\x66\x65nce_items\x18\x02 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemInt\x12\x46\n\x0brally_items\x18\x03 \x03(\x0b\x32\x31.magothy.protobuf.autopilot.MavlinkMissionItemIntb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'autopilot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ERROR']._serialized_start=80
  _globals['_ERROR']._serialized_end=120
  _globals['_POSITION']._serialized_start=122
  _globals['_POSITION']._serialized_end=177
  _globals['_ANGULARRATE']._serialized_start=179
  _globals['_ANGULARRATE']._serialized_end=237
  _globals['_ACCELERATION']._serialized_start=239
  _globals['_ACCELERATION']._serialized_end=301
  _globals['_MAGNETICFIELD']._serialized_start=303
  _globals['_MAGNETICFIELD']._serialized_end=369
  _globals['_EULER']._serialized_start=371
  _globals['_EULER']._serialized_end=436
  _globals['_BODYVELOCITY']._serialized_start=438
  _globals['_BODYVELOCITY']._serialized_end=497
  _globals['_INERTIALVELOCITY']._serialized_start=499
  _globals['_INERTIALVELOCITY']._serialized_end=572
  _globals['_WATERCURRENT']._serialized_start=574
  _globals['_WATERCURRENT']._serialized_end=630
  _globals['_FUELGAUGE']._serialized_start=632
  _globals['_FUELGAUGE']._serialized_end=714
  _globals['_VEHICLEDATA']._serialized_start=717
  _globals['_VEHICLEDATA']._serialized_end=3706
  _globals['_VEHICLEDATA_DATASOURCE']._serialized_start=3268
  _globals['_VEHICLEDATA_DATASOURCE']._serialized_end=3447
  _globals['_AHRSIF']._serialized_start=3709
  _globals['_AHRSIF']._serialized_end=4117
  _globals['_ALTITUDEIF']._serialized_start=4119
  _globals['_ALTITUDEIF']._serialized_end=4171
  _globals['_BATTERYIF']._serialized_start=4174
  _globals['_BATTERYIF']._serialized_end=4327
  _globals['_DEPTHIF']._serialized_start=4329
  _globals['_DEPTHIF']._serialized_end=4372
  _globals['_EFFECTORIF']._serialized_start=4374
  _globals['_EFFECTORIF']._serialized_end=4403
  _globals['_INSIF']._serialized_start=4406
  _globals['_INSIF']._serialized_end=5162
  _globals['_GPSIF']._serialized_start=5165
  _globals['_GPSIF']._serialized_end=6224
  _globals['_GPSIF_RMCDATA']._serialized_start=5373
  _globals['_GPSIF_RMCDATA']._serialized_end=5572
  _globals['_GPSIF_GGADATA']._serialized_start=5575
  _globals['_GPSIF_GGADATA']._serialized_end=5991
  _globals['_GPSIF_GGADATA_FIXQUALITY']._serialized_start=5770
  _globals['_GPSIF_GGADATA_FIXQUALITY']._serialized_end=5923
  _globals['_GPSIF_GSTDATA']._serialized_start=5994
  _globals['_GPSIF_GSTDATA']._serialized_end=6185
  _globals['_OBSTACLEIF']._serialized_start=6227
  _globals['_OBSTACLEIF']._serialized_end=6879
  _globals['_OBSTACLEIF_CIRCLE']._serialized_start=6615
  _globals['_OBSTACLEIF_CIRCLE']._serialized_end=6695
  _globals['_OBSTACLEIF_POLYGON']._serialized_start=6697
  _globals['_OBSTACLEIF_POLYGON']._serialized_end=6762
  _globals['_OBSTACLEIF_ZONETYPE']._serialized_start=6764
  _globals['_OBSTACLEIF_ZONETYPE']._serialized_end=6811
  _globals['_OBSTACLES']._serialized_start=6882
  _globals['_OBSTACLES']._serialized_end=7025
  _globals['_PATH']._serialized_start=7028
  _globals['_PATH']._serialized_end=7537
  _globals['_VEHICLESTATEIF']._serialized_start=7540
  _globals['_VEHICLESTATEIF']._serialized_end=8440
  _globals['_VEHICLESTATEIF_HEALTHITEM']._serialized_start=7865
  _globals['_VEHICLESTATEIF_HEALTHITEM']._serialized_end=7979
  _globals['_VEHICLESTATEIF_FAULTRESPONSE']._serialized_start=7981
  _globals['_VEHICLESTATEIF_FAULTRESPONSE']._serialized_end=8108
  _globals['_VEHICLESTATEIF_MODE']._serialized_start=8111
  _globals['_VEHICLESTATEIF_MODE']._serialized_end=8273
  _globals['_VEHICLESTATEIF_FAULTRESPONSETYPE']._serialized_start=8276
  _globals['_VEHICLESTATEIF_FAULTRESPONSETYPE']._serialized_end=8421
  _globals['_MAVLINKMISSIONITEMINT']._serialized_start=8443
  _globals['_MAVLINKMISSIONITEMINT']._serialized_end=8718
  _globals['_MAVLINKMISSION']._serialized_start=8721
  _globals['_MAVLINKMISSION']._serialized_end=8955
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vision.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cvision.proto\x12\x17magothy.protobuf.vision\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"]\n\x05\x43olor\x12\x0b\n\x03red\x18\x01 \x01(\x02\x12\r\n\x05green\x18\x02 \x01(\x02\x12\x0c\n\x04\x62lue\x18\x03 \x01(\x02\x12*\n\x05\x61lpha\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xb5\x01\n\x0f\x46ramePrediction\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\x12\x12\n\nconfidence\x18\x05 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x06 \x01(\x05\x12\x12\n\nclass_name\x18\x07 \x01(\t\x12\x33\n\x0b\x63lass_color\x18\x08 \x01(\x0b\x32\x1e.magothy.protobuf.vision.Color\"\xc5\x01\n\x05\x46rame\x12\x14\n\x0c\x66rame_number\x18\x01 \x01(\x04\x12/\n\x0bttag_system\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x03 \x01(\x04\x12\x1e\n\x16prediction_duration_ms\x18\x04 \x01(\r\x12=\n\x0bpredictions\x18\x05 \x03(\x0b\x32(.magothy.protobuf.vision.FramePrediction\"\xc3\x02\n\x0cOccupancyMap\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x38\n\x04type\x18\x03 \x01(\x0e\x32*.magothy.protobuf.vision.OccupancyMap.Type\x12\x0f\n\x07lat_deg\x18\x04 \x01(\x01\x12\x0f\n\x07lon_deg\x18\x05 \x01(\x01\x12\x0f\n\x07width_m\x18\x06 \x01(\x01\x12\x10\n\x08height_m\x18\x07 \x01(\x01\x12\x10\n\x08width_px\x18\x08 \x01(\r\x12\x11\n\theight_px\x18\t \x01(\r\x12\x0c\n\x04grid\x18\n \x01(\x0c\"8\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x0c\n\x08OCCUPIED\x10\x02\x12\n\n\x06MERGED\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vision_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_COLOR']._serialized_start=106
  _globals['_COLOR']._serialized_end=199
  _globals['_FRAMEPREDICTION']._serialized_start=202
  _globals['_FRAMEPREDICTION']._serialized_end=383
  _globals['_FRAME']._serialized_start=386
  _globals['_FRAME']._serialized_end=583
  _globals['_OCCUPANCYMAP']._serialized_start=586
  _globals['_OCCUPANCYMAP']._serialized_end=909
  _globals['_OCCUPANCYMAP_TYPE']._serialized_start=853
  _globals['_OCCUPANCYMAP_TYPE']._serialized_end=909
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STATE_OFF: _ClassVar[State]
    STATE_STANDBY: _ClassVar[State]
    STATE_WARMING_UP: _ClassVar[State]
    STATE_TIMED_IDLE: _ClassVar[State]
    STATE_STOPPING: _ClassVar[State]
    STATE_SPINNING_DOWN: _ClassVar[State]
    STATE_STARTING: _ClassVar[State]
    STATE_SPINNING_UP: _ClassVar[State]
    STATE_TRANSMIT: _ClassVar[State]

class CommandType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    COMMAND_NONE: _ClassVar[CommandType]
    COMMAND_TURN_ON: _ClassVar[CommandType]
    COMMAND_TURN_OFF: _ClassVar[CommandType]
    COMMAND_SET_RANGE: _ClassVar[CommandType]
    COMMAND_SET_GAIN: _ClassVar[CommandType]
STATE_OFF: State
STATE_STANDBY: State
STATE_WARMING_UP: State
STATE_TIMED_IDLE: State
STATE_STOPPING: State
STATE_SPINNING_DOWN: State
STATE_STARTING: State
STATE_SPINNING_UP: State
STATE_TRANSMIT: State
COMMAND_NONE: CommandType
COMMAND_TURN_ON: CommandType
COMMAND_TURN_OFF: CommandType
COMMAND_SET_RANGE: CommandType
COMMAND_SET_GAIN: CommandType

class Pose(_message.Message):
    __slots__ = ("lat_deg", "lon_deg", "heading_deg")
    LAT_DEG_FIELD_NUMBER: _ClassVar[int]
    LON_DEG_FIELD_NUMBER: _ClassVar[int]
    HEADING_DEG_FIELD_NUMBER: _ClassVar[int]
    lat_deg: float
    lon_deg: float
    heading_deg: float
    def __init__(self, lat_deg: _Optional[float] = ..., lon_deg: _Optional[float] = ..., heading_deg: _Optional[float] = ...) -> None: ...

class Spokes(_message.Message):
    __slots__ = ("num_spoke", "first_spoke_index", "range_m", "spokes")
    NUM_SPOKE_FIELD_NUMBER: _ClassVar[int]
    FIRST_SPOKE_INDEX_FIELD_NUMBER: _ClassVar[int]
    RANGE_M_FIELD_NUMBER: _ClassVar[int]
    SPOKES_FIELD_NUMBER: _ClassVar[int]
    num_spoke: int
    first_spoke_index: int
    range_m: float
    spokes: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, num_spoke: _Optional[int] = ..., first_spoke_index: _Optional[int] = ..., range_m: _Optional[float] = ..., spokes: _Optional[_Iterable[bytes]] = ...) -> None: ...

class Info(_message.Message):
    __slots__ = ("timestamp", "ttag_steady_ns", "state", "gain", "rain", "sea", "range", "scan_speed", "spokes", "pose")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    GAIN_FIELD_NUMBER: _ClassVar[int]
    RAIN_FIELD_NUMBER: _ClassVar[int]
    SEA_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    SCAN_SPEED_FIELD_NUMBER: _ClassVar[int]
    SPOKES_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    state: State
    gain: int
    rain: int
    sea: int
    range: int
    scan_speed: int
    spokes: Spokes
    pose: Pose
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., state: _Optional[_Union[State, str]] = ..., gain: _Optional[int] = ..., rain: _Optional[int] = ..., sea: _Optional[int] = ..., range: _Optional[int] = ..., scan_speed: _Optional[int] = ..., spokes: _Optional[_Union[Spokes, _Mapping]] = ..., pose: _Optional[_Union[Pose, _Mapping]] = ...) -> None: ...

class Command(_message.Message):
    __slots__ = ("command", "value")
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    command: CommandType
    value: int
    def __init__(self, command: _Optional[_Union[CommandType, str]] = ..., value: _Optional[int] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Range(_message.Message):
    __slots__ = ("ttag_system", "ttag_steady_ns", "type", "range_m", "range_uncertainty_m", "field_of_view_deg")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[Range.Type]
        ULTRASOUND: _ClassVar[Range.Type]
        INFRARED: _ClassVar[Range.Type]
        LASER: _ClassVar[Range.Type]
    UNKNOWN: Range.Type
    ULTRASOUND: Range.Type
    INFRARED: Range.Type
    LASER: Range.Type
    TTAG_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    RANGE_M_FIELD_NUMBER: _ClassVar[int]
    RANGE_UNCERTAINTY_M_FIELD_NUMBER: _ClassVar[int]
    FIELD_OF_VIEW_DEG_FIELD_NUMBER: _ClassVar[int]
    ttag_system: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    type: Range.Type
    range_m: float
    range_uncertainty_m: float
    field_of_view_deg: float
    def __init__(self, ttag_system: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., type: _Optional[_Union[Range.Type, str]] = ..., range_m: _Optional[float] = ..., range_uncertainty_m: _Optional[float] = ..., field_of_view_deg: _Optional[float] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Error(_message.Message):
    __slots__ = ("x", "y", "z")
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    x: float
    y: float
    z: float
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., z: _Optional[float] = ...) -> None: ...

class Position(_message.Message):
    __slots__ = ("latitude_deg", "longitude_deg")
    LATITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
    LONGITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
    latitude_deg: float
    longitude_deg: float
    def __init__(self, latitude_deg: _Optional[float] = ..., longitude_deg: _Optional[float] = ...) -> None: ...

class AngularRate(_message.Message):
    __slots__ = ("x_dps", "y_dps", "z_dps")
    X_DPS_FIELD_NUMBER: _ClassVar[int]
    Y_DPS_FIELD_NUMBER: _ClassVar[int]
    Z_DPS_FIELD_NUMBER: _ClassVar[int]
    x_dps: float
    y_dps: float
    z_dps: float
    def __init__(self, x_dps: _Optional[float] = ..., y_dps: _Optional[float] = ..., z_dps: _Optional[float] = ...) -> None: ...

class Acceleration(_message.Message):
    __slots__ = ("x_mps2", "y_mps2", "z_mps2")
    X_MPS2_FIELD_NUMBER: _ClassVar[int]
    Y_MPS2_FIELD_NUMBER: _ClassVar[int]
    Z_MPS2_FIELD_NUMBER: _ClassVar[int]
    x_mps2: float
    y_mps2: float
    z_mps2: float
    def __init__(self, x_mps2: _Optional[float] = ..., y_mps2: _Optional[float] = ..., z_mps2: _Optional[float] = ...) -> None: ...

class MagneticField(_message.Message):
    __slots__ = ("x_gauss", "y_gauss", "z_gauss")
    X_GAUSS_FIELD_NUMBER: _ClassVar[int]
    Y_GAUSS_FIELD_NUMBER: _ClassVar[int]
    Z_GAUSS_FIELD_NUMBER: _ClassVar[int]
    x_gauss: float
    y_gauss: float
    z_gauss: float
    def __init__(self, x_gauss: _Optional[float] = ..., y_gauss: _Optional[float] = ..., z_gauss: _Optional[float] = ...) -> None: ...

class Euler(_message.Message):
    __slots__ = ("roll_deg", "pitch_deg", "heading_deg")
    ROLL_DEG_FIELD_NUMBER: _ClassVar[int]
    PITCH_DEG_FIELD_NUMBER: _ClassVar[int]
    HEADING_DEG_FIELD_NUMBER: _ClassVar[int]
    roll_deg: float
    pitch_deg: float
    heading_deg: float
    def __init__(self, roll_deg: _Optional[float] = ..., pitch_deg: _Optional[float] = ..., heading_deg: _Optional[float] = ...) -> None: ...

class BodyVelocity(_message.Message):
    __slots__ = ("x_mps", "y_mps", "z_mps")
    X_MPS_FIELD_NUMBER: _ClassVar[int]
    Y_MPS_FIELD_NUMBER: _ClassVar[int]
    Z_MPS_FIELD_NUMBER: _ClassVar[int]
    x_mps: float
    y_mps: float
    z_mps: float
    def __init__(self, x_mps: _Optional[float] = ..., y_mps: _Optional[float] = ..., z_mps: _Optional[float] = ...) -> None: ...

class InertialVelocity(_message.Message):
    __slots__ = ("north_mps", "east_mps", "down_mps")
    NORTH_MPS_FIELD_NUMBER: _ClassVar[int]
    EAST_MPS_FIELD_NUMBER: _ClassVar[int]
    DOWN_MPS_FIELD_NUMBER: _ClassVar[int]
    north_mps: float
    east_mps: float
    down_mps: float
    def __init__(self, north_mps: _Optional[float] = ..., east_mps: _Optional[float] = ..., down_mps: _Optional[float] = ...) -> None: ...

class WaterCurrent(_message.Message):
    __slots__ = ("speed_mps", "direction_deg")
    SPEED_MPS_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_DEG_FIELD_NUMBER: _ClassVar[int]
    speed_mps: float
    direction_deg: float
    def __init__(self, speed_mps: _Optional[float] = ..., direction_deg: _Optional[float] = ...) -> None: ...

class FuelGauge(_message.Message):
    __slots__ = ("voltage_V", "current_A", "state_of_charge_percent")
    VOLTAGE_V_FIELD_NUMBER: _ClassVar[int]
    CURRENT_A_FIELD_NUMBER: _ClassVar[int]
    STATE_OF_CHARGE_PERCENT_FIELD_NUMBER: _ClassVar[int]
    voltage_V: float
    current_A: float
    state_of_charge_percent: float
    def __init__(self, voltage_V: _Optional[float] = ..., current_A: _Optional[float] = ..., state_of_charge_percent: _Optional[float] = ...) -> None: ...

class VehicleData(_message.Message):
    __slots__ = ("position", "position_source", "position_ttag_ns_steady", "position_error_m", "position_error_source", "position_error_ttag_ns_steady", "attitude", "attitude_source", "attitude_ttag_ns_steady", "attitude_error_deg", "attitude_error_source", "attitude_error_ttag_ns_steady", "angular_rate", "angular_rate_source", "angular_rate_ttag_ns_steady", "acceleration", "acceleration_source", "acceleration_ttag_ns_steady", "magnetic_field", "magnetic_field_source", "magnetic_field_ttag_ns_steady", "depth_m", "depth_source", "depth_ttag_ns_steady", "altitude_m", "altitude_source", "altitude_ttag_ns_steady", "speed_mps", "speed_source", "speed_ttag_ns_steady", "course_deg", "course_source", "course_ttag_ns_steady", "body_velocity", "body_velocity_source", "body_velocity_ttag_ns_steady", "water_current", "water_current_source", "water_current_ttag_ns_steady", "water_relative_speed_mps", "water_relative_speed_source", "water_relative_speed_ttag_ns_steady", "fuel_gauge", "fuel_gauge_source", "fuel_gauge_ttag_ns_steady")
    class DataSource(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DS_NODATA: _ClassVar[VehicleData.DataSource]
        DS_IMU: _ClassVar[VehicleData.DataSource]
        DS_AHRS: _ClassVar[VehicleData.DataSource]
        DS_GPS: _ClassVar[VehicleData.DataSource]
        DS_DEPTH: _ClassVar[VehicleData.DataSource]
        DS_ALTITUDE: _ClassVar[VehicleData.DataSource]
        DS_SPEED: _ClassVar[VehicleData.DataSource]
        DS_ESTIMATION: _ClassVar[VehicleData.DataSource]
        DS_COMPUTATION: _ClassVar[VehicleData.DataSource]
        DS_SIMULATION: _ClassVar[VehicleData.DataSource]
        DS_INS: _ClassVar[VehicleData.DataSource]
    DS_NODATA: VehicleData.DataSource
    DS_IMU: VehicleData.DataSource
    DS_AHRS: VehicleData.DataSource
    DS_GPS: VehicleData.DataSource
    DS_DEPTH: VehicleData.DataSource
    DS_ALTITUDE: VehicleData.DataSource
    DS_SPEED: VehicleData.DataSource
    DS_ESTIMATION: VehicleData.DataSource
    DS_COMPUTATION: VehicleData.DataSource
    DS_SIMULATION: VehicleData.DataSource
    DS_INS: VehicleData.DataSource
    POSITION_FIELD_NUMBER: _ClassVar[int]
    POSITION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    POSITION_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    POSITION_ERROR_M_FIELD_NUMBER: _ClassVar[int]
    POSITION_ERROR_SOURCE_FIELD_NUMBER: _ClassVar[int]
    POSITION_ERROR_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_ERROR_DEG_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_ERROR_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ATTITUDE_ERROR_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_RATE_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_RATE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_RATE_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    MAGNETIC_FIELD_FIELD_NUMBER: _ClassVar[int]
    MAGNETIC_FIELD_SOURCE_FIELD_NUMBER: _ClassVar[int]
    MAGNETIC_FIELD_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    DEPTH_M_FIELD_NUMBER: _ClassVar[int]
    DEPTH_SOURCE_FIELD_NUMBER: _ClassVar[int]
    DEPTH_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_M_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    SPEED_MPS_FIELD_NUMBER: _ClassVar[int]
    SPEED_SOURCE_FIELD_NUMBER: _ClassVar[int]
    SPEED_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    COURSE_DEG_FIELD_NUMBER: _ClassVar[int]
    COURSE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    COURSE_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    BODY_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    BODY_VELOCITY_SOURCE_FIELD_NUMBER: _ClassVar[int]
    BODY_VELOCITY_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    WATER_CURRENT_FIELD_NUMBER: _ClassVar[int]
    WATER_CURRENT_SOURCE_FIELD_NUMBER: _ClassVar[int]
    WATER_CURRENT_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    WATER_RELATIVE_SPEED_MPS_FIELD_NUMBER: _ClassVar[int]
    WATER_RELATIVE_SPEED_SOURCE_FIELD_NUMBER: _ClassVar[int]
    WATER_RELATIVE_SPEED_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    FUEL_GAUGE_FIELD_NUMBER: _ClassVar[int]
    FUEL_GAUGE_SOURCE_FIELD_NUMBER: _ClassVar[int]
    FUEL_GAUGE_TTAG_NS_STEADY_FIELD_NUMBER: _ClassVar[int]
    position: Position
    position_source: VehicleData.DataSource
    position_ttag_ns_steady: int
    position_error_m: Error
    position_error_source: VehicleData.DataSource
    position_error_ttag_ns_steady: int
    attitude: Euler
    attitude_source: VehicleData.DataSource
    attitude_ttag_ns_steady: int
    attitude_error_deg: Error
    attitude_error_source: VehicleData.DataSource
    attitude_error_ttag_ns_steady: int
    angular_rate: AngularRate
    angular_rate_source: VehicleData.DataSource
    angular_rate_ttag_ns_steady: int
    acceleration: Acceleration
    acceleration_source: VehicleData.DataSource
    acceleration_ttag_ns_steady: int
    magnetic_field: MagneticField
    magnetic_field_source: VehicleData.DataSource
    magnetic_field_ttag_ns_steady: int
    depth_m: float
    depth_source: VehicleData.DataSource
    depth_ttag_ns_steady: int
    altitude_m: float
    altitude_source: VehicleData.DataSource
    altitude_ttag_ns_steady: int
    speed_mps: float
    speed_source: VehicleData.DataSource
    speed_ttag_ns_steady: int
    course_deg: float
    course_source: VehicleData.DataSource
    course_ttag_ns_steady: int
    body_velocity: BodyVelocity
    body_velocity_source: VehicleData.DataSource
    body_velocity_ttag_ns_steady: int
    water_current: WaterCurrent
    water_current_source: VehicleData.DataSource
    water_current_ttag_ns_steady: int
    water_relative_speed_mps: float
    water_relative_speed_source: VehicleData.DataSource
    water_relative_speed_ttag_ns_steady: int
    fuel_gauge: FuelGauge
    fuel_gauge_source: VehicleData.DataSource
    fuel_gauge_ttag_ns_steady: int
    def __init__(self, position: _Optional[_Union[Position, _Mapping]] = ..., position_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., position_ttag_ns_steady: _Optional[int] = ..., position_error_m: _Optional[_Union[Error, _Mapping]] = ..., position_error_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., position_error_ttag_ns_steady: _Optional[int] = ..., attitude: _Optional[_Union[Euler, _Mapping]] = ..., attitude_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., attitude_ttag_ns_steady: _Optional[int] = ..., attitude_error_deg: _Optional[_Union[Error, _Mapping]] = ..., attitude_error_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., attitude_error_ttag_ns_steady: _Optional[int] = ..., angular_rate: _Optional[_Union[AngularRate, _Mapping]] = ..., angular_rate_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., angular_rate_ttag_ns_steady: _Optional[int] = ..., acceleration: _Optional[_Union[Acceleration, _Mapping]] = ..., acceleration_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., acceleration_ttag_ns_steady: _Optional[int] = ..., magnetic_field: _Optional[_Union[MagneticField, _Mapping]] = ..., magnetic_field_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., magnetic_field_ttag_ns_steady: _Optional[int] = ..., depth_m: _Optional[float] = ..., depth_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., depth_ttag_ns_steady: _Optional[int] = ..., altitude_m: _Optional[float] = ..., altitude_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., altitude_ttag_ns_steady: _Optional[int] = ..., speed_mps: _Optional[float] = ..., speed_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., speed_ttag_ns_steady: _Optional[int] = ..., course_deg: _Optional[float] = ..., course_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., course_ttag_ns_steady: _Optional[int] = ..., body_velocity: _Optional[_Union[BodyVelocity, _Mapping]] = ..., body_velocity_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., body_velocity_ttag_ns_steady: _Optional[int] = ..., water_current: _Optional[_Union[WaterCurrent, _Mapping]] = ..., water_current_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., water_current_ttag_ns_steady: _Optional[int] = ..., water_relative_speed_mps: _Optional[float] = ..., water_relative_speed_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., water_relative_speed_ttag_ns_steady: _Optional[int] = ..., fuel_gauge: _Optional[_Union[FuelGauge, _Mapping]] = ..., fuel_gauge_source: _Optional[_Union[VehicleData.DataSource, str]] = ..., fuel_gauge_ttag_ns_steady: _Optional[int] = ...) -> None: ...

class AhrsIf(_message.Message):
    __slots__ = ("angular_rate", "acceleration", "magfield", "euler", "euler_error_deg")
    ANGULAR_RATE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    MAGFIELD_FIELD_NUMBER: _ClassVar[int]
    EULER_FIELD_NUMBER: _ClassVar[int]
    EULER_ERROR_DEG_FIELD_NUMBER: _ClassVar[int]
    angular_rate: AngularRate
    acceleration: Acceleration
    magfield: MagneticField
    euler: Euler
    euler_error_deg: Error
    def __init__(self, angular_rate: _Optional[_Union[AngularRate, _Mapping]] = ..., acceleration: _Optional[_Union[Acceleration, _Mapping]] = ..., magfield: _Optional[_Union[MagneticField, _Mapping]] = ..., euler: _Optional[_Union[Euler, _Mapping]] = ..., euler_error_deg: _Optional[_Union[Error, _Mapping]] = ...) -> None: ...

class AltitudeIf(_message.Message):
    __slots__ = ("altitude_m",)
    ALTITUDE_M_FIELD_NUMBER: _ClassVar[int]
    altitude_m: float
    def __init__(self, altitude_m: _Optional[float] = ...) -> None: ...

class BatteryIf(_message.Message):
    __slots__ = ("voltage_V", "current_A", "state_of_charge_percent")
    VOLTAGE_V_FIELD_NUMBER: _ClassVar[int]
    CURRENT_A_FIELD_NUMBER: _ClassVar[int]
    STATE_OF_CHARGE_PERCENT_FIELD_NUMBER: _ClassVar[int]
    voltage_V: float
    current_A: float
    state_of_charge_percent: int
    def __init__(self, voltage_V: _Optional[float] = ..., current_A: _Optional[float] = ..., state_of_charge_percent: _Optional[int] = ...) -> None: ...

class DepthIf(_message.Message):
    __slots__ = ("depth_m",)
    DEPTH_M_FIELD_NUMBER: _ClassVar[int]
    depth_m: float
    def __init__(self, depth_m: _Optional[float] = ...) -> None: ...

class EffectorIf(_message.Message):
    __slots__ = ("command",)
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    command: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, command: _Optional[_Iterable[float]] = ...) -> None: ...

class InsIf(_message.Message):
    __slots__ = ("angular_rate", "acceleration", "magfield", "euler", "euler_error_deg", "body_velocity", "position", "position_error_m", "inertial_velocity")
    ANGULAR_RATE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    MAGFIELD_FIELD_NUMBER: _ClassVar[int]
    EULER_FIELD_NUMBER: _ClassVar[int]
    EULER_ERROR_DEG_FIELD_NUMBER: _ClassVar[int]
    BODY_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    POSITION_ERROR_M_FIELD_NUMBER: _ClassVar[int]
    INERTIAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    angular_rate: AngularRate
    acceleration: Acceleration
    magfield: MagneticField
    euler: Euler
    euler_error_deg: Error
    body_velocity: BodyVelocity
    position: Position
    position_error_m: Error
    inertial_velocity: InertialVelocity
    def __init__(self, angular_rate: _Optional[_Union[AngularRate, _Mapping]] = ..., acceleration: _Optional[_Union[Acceleration, _Mapping]] = ..., magfield: _Optional[_Union[MagneticField, _Mapping]] = ..., euler: _Optional[_Union[Euler, _Mapping]] = ..., euler_error_deg: _Optional[_Union[Error, _Mapping]] = ..., body_velocity: _Optional[_Union[BodyVelocity, _Mapping]] = ..., position: _Optional[_Union[Position, _Mapping]] = ..., position_error_m: _Optional[_Union[Error, _Mapping]] = ..., inertial_velocity: _Optional[_Union[InertialVelocity, _Mapping]] = ...) -> None: ...

class GpsIf(_message.Message):
    __slots__ = ("rmc_data", "gga_data", "gst_data")
    class RmcData(_message.Message):
        __slots__ = ("latitude_deg", "longitude_deg", "ground_speed_kt", "course_true_deg")
        LATITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
        LONGITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
        GROUND_SPEED_KT_FIELD_NUMBER: _ClassVar[int]
        COURSE_TRUE_DEG_FIELD_NUMBER: _ClassVar[int]
        latitude_deg: float
        longitude_deg: float
        ground_speed_kt: float
        course_true_deg: float
        def __init__(self, latitude_deg: _Optional[float] = ..., longitude_deg: _Optional[float] = ..., ground_speed_kt: _Optional[float] = ..., course_true_deg: _Optional[float] = ...) -> None: ...
    class GgaData(_message.Message):
        __slots__ = ("latitude_deg", "longitude_deg", "altitude_m", "num_satellite", "fix_quality")
        class FixQuality(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = ()
            FQ_INVALID: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_GPS: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_DGPS: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_PPS: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_RTK_FIXED: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_RTK_FLOAT: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_ESTIMATED: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_MANUAL: _ClassVar[GpsIf.GgaData.FixQuality]
            FQ_SIMULATION: _ClassVar[GpsIf.GgaData.FixQuality]
        FQ_INVALID: GpsIf.GgaData.FixQuality
        FQ_GPS: GpsIf.GgaData.FixQuality
        FQ_DGPS: GpsIf.GgaData.FixQuality
        FQ_PPS: GpsIf.GgaData.FixQuality
        FQ_RTK_FIXED: GpsIf.GgaData.FixQuality
        FQ_RTK_FLOAT: GpsIf.GgaData.FixQuality
        FQ_ESTIMATED: GpsIf.GgaData.FixQuality
        FQ_MANUAL: GpsIf.GgaData.FixQuality
        FQ_SIMULATION: GpsIf.GgaData.FixQuality
        LATITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
        LONGITUDE_DEG_FIELD_NUMBER: _ClassVar[int]
        ALTITUDE_M_FIELD_NUMBER: _ClassVar[int]
        NUM_SATELLITE_FIELD_NUMBER: _ClassVar[int]
        FIX_QUALITY_FIELD_NUMBER: _ClassVar[int]
        latitude_deg: float
        longitude_deg: float
        altitude_m: float
        num_satellite: int
        fix_quality: GpsIf.GgaData.FixQuality
        def __init__(self, latitude_deg: _Optional[float] = ..., longitude_deg: _Optional[float] = ..., altitude_m: _Optional[float] = ..., num_satellite: _Optional[int] = ..., fix_quality: _Optional[_Union[GpsIf.GgaData.FixQuality, str]] = ...) -> None: ...
    class GstData(_message.Message):
        __slots__ = ("std_latitude_error_m", "std_longitude_error_m", "std_altitude_error_m")
        STD_LATITUDE_ERROR_M_FIELD_NUMBER: _ClassVar[int]
        STD_LONGITUDE_ERROR_M_FIELD_NUMBER: _ClassVar[int]
        STD_ALTITUDE_ERROR_M_FIELD_NUMBER: _ClassVar[int]
        std_latitude_error_m: float
        std_longitude_error_m: float
        std_altitude_error_m: float
        def __init__(self, std_latitude_error_m: _Optional[float] = ..., std_longitude_error_m: _Optional[float] = ..., std_altitude_error_m: _Optional[float] = ...) -> None: ...
    RMC_DATA_FIELD_NUMBER: _ClassVar[int]
    GGA_DATA_FIELD_NUMBER: _ClassVar[int]
    GST_DATA_FIELD_NUMBER: _ClassVar[int]
    rmc_data: GpsIf.RmcData
    gga_data: GpsIf.GgaData
    gst_data: GpsIf.GstData
    def __init__(self, rmc_data: _Optional[_Union[GpsIf.RmcData, _Mapping]] = ..., gga_data: _Optional[_Union[GpsIf.GgaData, _Mapping]] = ..., gst_data: _Optional[_Union[GpsIf.GstData, _Mapping]] = ...) -> None: ...

class ObstacleIf(_message.Message):
    __slots__ = ("id", "circle", "polygon", "zone_type", "is_stationary", "lifespan_s", "course_deg", "speed_mps", "point_of_interest")
    class ZoneType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ZONE_KEEP_OUT: _ClassVar[ObstacleIf.ZoneType]
        ZONE_KEEP_IN: _ClassVar[ObstacleIf.ZoneType]
    ZONE_KEEP_OUT: ObstacleIf.ZoneType
    ZONE_KEEP_IN: ObstacleIf.ZoneType
    class Circle(_message.Message):
        __slots__ = ("origin", "radius_m")
        ORIGIN_FIELD_NUMBER: _ClassVar[int]
        RADIUS_M_FIELD_NUMBER: _ClassVar[int]
        origin: Position
        radius_m: float
        def __init__(self, origin: _Optional[_Union[Position, _Mapping]] = ..., radius_m: _Optional[float] = ...) -> None: ...
    class Polygon(_message.Message):
        __slots__ = ("vertices",)
        VERTICES_FIELD_NUMBER: _ClassVar[int]
        vertices: _containers.RepeatedCompositeFieldContainer[Position]
        def __init__(self, vertices: _Optional[_Iterable[_Union[Position, _Mapping]]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CIRCLE_FIELD_NUMBER: _ClassVar[int]
    POLYGON_FIELD_NUMBER: _ClassVar[int]
    ZONE_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_STATIONARY_FIELD_NUMBER: _ClassVar[int]
    LIFESPAN_S_FIELD_NUMBER: _ClassVar[int]
    COURSE_DEG_FIELD_NUMBER: _ClassVar[int]
    SPEED_MPS_FIELD_NUMBER: _ClassVar[int]
    POINT_OF_INTEREST_FIELD_NUMBER: _ClassVar[int]
    id: str
    circle: ObstacleIf.Circle
    polygon: ObstacleIf.Polygon
    zone_type: ObstacleIf.ZoneType
    is_stationary: bool
    lifespan_s: float
    course_deg: float
    speed_mps: float
    point_of_interest: Position
    def __init__(self, id: _Optional[str] = ..., circle: _Optional[_Union[ObstacleIf.Circle, _Mapping]] = ..., polygon: _Optional[_Union[ObstacleIf.Polygon, _Mapping]] = ..., zone_type: _Optional[_Union[ObstacleIf.ZoneType, str]] = ..., is_stationary: bool = ..., lifespan_s: _Optional[float] = ..., course_deg: _Optional[float] = ..., speed_mps: _Optional[float] = ..., point_of_interest: _Optional[_Union[Position, _Mapping]] = ...) -> None: ...

class Obstacles(_message.Message):
    __slots__ = ("ttag_system", "ttag_steady_ns", "obstacles")
    TTAG_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    OBSTACLES_FIELD_NUMBER: _ClassVar[int]
    ttag_system: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    obstacles: _containers.RepeatedCompositeFieldContainer[ObstacleIf]
    def __init__(self, ttag_system: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., obstacles: _Optional[_Iterable[_Union[ObstacleIf, _Mapping]]] = ...) -> None: ...

class Path(_message.Message):
    __slots__ = ("ttag_system", "ttag_steady_ns", "path", "obstacles", "speed_mps", "start", "end_local", "end_global", "global_path")
    TTAG_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    OBSTACLES_FIELD_NUMBER: _ClassVar[int]
    SPEED_MPS_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    END_LOCAL_FIELD_NUMBER: _ClassVar[int]
    END_GLOBAL_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_PATH_FIELD_NUMBER: _ClassVar[int]
    ttag_system: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    path: _containers.RepeatedCompositeFieldContainer[Position]
    obstacles: _containers.RepeatedCompositeFieldContainer[ObstacleIf]
    speed_mps: float
    start: Position
    end_local: Position
    end_global: Position
    global_path: _containers.RepeatedCompositeFieldContainer[Position]
    def __init__(self, ttag_system: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., path: _Optional[_Iterable[_Union[Position, _Mapping]]] = ..., obstacles: _Optional[_Iterable[_Union[ObstacleIf, _Mapping]]] = ..., speed_mps: _Optional[float] = ..., start: _Optional[_Union[Position, _Mapping]] = ..., end_local: _Optional[_Union[Position, _Mapping]] = ..., end_global: _Optional[_Union[Position, _Mapping]] = ..., global_path: _Optional[_Iterable[_Union[Position, _Mapping]]] = ...) -> None: ...

class VehicleStateIf(_message.Message):
    __slots__ = ("ttag_ns", "vehicle_data", "mode", "health_items", "fault_response")
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VS_STANDBY: _ClassVar[VehicleStateIf.Mode]
        VS_MANUAL: _ClassVar[VehicleStateIf.Mode]
        VS_HEALTHY_MISSION: _ClassVar[VehicleStateIf.Mode]
        VS_UNHEALTHY_MISSION: _ClassVar[VehicleStateIf.Mode]
        VS_LOITER: _ClassVar[VehicleStateIf.Mode]
        VS_MISSION_PLANNING: _ClassVar[VehicleStateIf.Mode]
        VS_UNHEALTHY_MISSION_PLANNING: _ClassVar[VehicleStateIf.Mode]
    VS_STANDBY: VehicleStateIf.Mode
    VS_MANUAL: VehicleStateIf.Mode
    VS_HEALTHY_MISSION: VehicleStateIf.Mode
    VS_UNHEALTHY_MISSION: VehicleStateIf.Mode
    VS_LOITER: VehicleStateIf.Mode
    VS_MISSION_PLANNING: VehicleStateIf.Mode
    VS_UNHEALTHY_MISSION_PLANNING: VehicleStateIf.Mode
    class FaultResponseType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FR_IGNORE: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_HALT: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_LOITER: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_GO_RALLY: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_GO_FIRST: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_GO_LAST: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_GO_LAUNCH: _ClassVar[VehicleStateIf.FaultResponseType]
        FR_CUSTOM: _ClassVar[VehicleStateIf.FaultResponseType]
    FR_IGNORE: VehicleStateIf.FaultResponseType
    FR_HALT: VehicleStateIf.FaultResponseType
    FR_LOITER: VehicleStateIf.FaultResponseType
    FR_GO_RALLY: VehicleStateIf.FaultResponseType
    FR_GO_FIRST: VehicleStateIf.FaultResponseType
    FR_GO_LAST: VehicleStateIf.FaultResponseType
    FR_GO_LAUNCH: VehicleStateIf.FaultResponseType
    FR_CUSTOM: VehicleStateIf.FaultResponseType
    class HealthItem(_message.Message):
        __slots__ = ("index", "uid", "sensor_id", "is_valid", "enabled", "is_healthy")
        INDEX_FIELD_NUMBER: _ClassVar[int]
        UID_FIELD_NUMBER: _ClassVar[int]
        SENSOR_ID_FIELD_NUMBER: _ClassVar[int]
        IS_VALID_FIELD_NUMBER: _ClassVar[int]
        ENABLED_FIELD_NUMBER: _ClassVar[int]
        IS_HEALTHY_FIELD_NUMBER: _ClassVar[int]
        index: int
        uid: str
        sensor_id: int
        is_valid: bool
        enabled: bool
        is_healthy: bool
        def __init__(self, index: _Optional[int] = ..., uid: _Optional[str] = ..., sensor_id: _Optional[int] = ..., is_valid: bool = ..., enabled: bool = ..., is_healthy: bool = ...) -> None: ...
    class FaultResponse(_message.Message):
        __slots__ = ("response_type", "health_item_index")
        RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
        HEALTH_ITEM_INDEX_FIELD_NUMBER: _ClassVar[int]
        response_type: VehicleStateIf.FaultResponseType
        health_item_index: int
        def __init__(self, response_type: _Optional[_Union[VehicleStateIf.FaultResponseType, str]] = ..., health_item_index: _Optional[int] = ...) -> None: ...
    TTAG_NS_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_DATA_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    HEALTH_ITEMS_FIELD_NUMBER: _ClassVar[int]
    FAULT_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    ttag_ns: int
    vehicle_data: VehicleData
    mode: VehicleStateIf.Mode
    health_items: _containers.RepeatedCompositeFieldContainer[VehicleStateIf.HealthItem]
    fault_response: VehicleStateIf.FaultResponse
    def __init__(self, ttag_ns: _Optional[int] = ..., vehicle_data: _Optional[_Union[VehicleData, _Mapping]] = ..., mode: _Optional[_Union[VehicleStateIf.Mode, str]] = ..., health_items: _Optional[_Iterable[_Union[VehicleStateIf.HealthItem, _Mapping]]] = ..., fault_response: _Optional[_Union[VehicleStateIf.FaultResponse, _Mapping]] = ...) -> None: ...

class MavlinkMissionItemInt(_message.Message):
    __slots__ = ("target_system", "target_component", "mission_type", "seq", "command", "frame", "current", "autocontinue", "param1", "param2", "param3", "param4", "x", "y", "z")
    TARGET_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TARGET_COMPONENT_FIELD_NUMBER: _ClassVar[int]
    MISSION_TYPE_FIELD_NUMBER: _ClassVar[int]
    SEQ_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    FRAME_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    AUTOCONTINUE_FIELD_NUMBER: _ClassVar[int]
    PARAM1_FIELD_NUMBER: _ClassVar[int]
    PARAM2_FIELD_NUMBER: _ClassVar[int]
    PARAM3_FIELD_NUMBER: _ClassVar[int]
    PARAM4_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    target_system: int
    target_component: int
    mission_type: int
    seq: int
    command: int
    frame: int
    current: bool
    autocontinue: bool
    param1: float
    param2: float
    param3: float
    param4: float
    x: int
    y: int
    z: float
    def __init__(self, target_system: _Optional[int] = ..., target_component: _Optional[int] = ..., mission_type: _Optional[int] = ..., seq: _Optional[int] = ..., command: _Optional[int] = ..., frame: _Optional[int] = ..., current: bool = ..., autocontinue: bool = ..., param1: _Optional[float] = ..., param2: _Optional[float] = ..., param3: _Optional[float] = ..., param4: _Optional[float] = ..., x: _Optional[int] = ..., y: _Optional[int] = ..., z: _Optional[float] = ...) -> None: ...

class MavlinkMission(_message.Message):
    __slots__ = ("mission_items", "fence_items", "rally_items")
    MISSION_ITEMS_FIELD_NUMBER: _ClassVar[int]
    FENCE_ITEMS_FIELD_NUMBER: _ClassVar[int]
    RALLY_ITEMS_FIELD_NUMBER: _ClassVar[int]
    mission_items: _containers.RepeatedCompositeFieldContainer[MavlinkMissionItemInt]
    fence_items: _containers.RepeatedCompositeFieldContainer[MavlinkMissionItemInt]
    rally_items: _containers.RepeatedCompositeFieldContainer[MavlinkMissionItemInt]
    def __init__(self, mission_items: _Optional[_Iterable[_Union[MavlinkMissionItemInt, _Mapping]]] = ..., fence_items: _Optional[_Iterable[_Union[MavlinkMissionItemInt, _Mapping]]] = ..., rally_items: _Optional[_Iterable[_Union[MavlinkMissionItemInt, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radar.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bradar.proto\x12\x16magothy.protobuf.radar\x1a\x1fgoogle/protobuf/timestamp.proto\"=\n\x04Pose\x12\x0f\n\x07lat_deg\x18\x01 \x01(\x01\x12\x0f\n\x07lon_deg\x18\x02 \x01(\x01\x12\x13\n\x0bheading_deg\x18\x03 \x01(\x02\"W\n\x06Spokes\x12\x11\n\tnum_spoke\x18\x01 \x01(\r\x12\x19\n\x11\x66irst_spoke_index\x18\x02 \x01(\r\x12\x0f\n\x07range_m\x18\x03 \x01(\x02\x12\x0e\n\x06spokes\x18\x04 \x03(\x0c\"\xc1\x02\n\x04Info\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\t \x01(\x04\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.magothy.protobuf.radar.State\x12\x0c\n\x04gain\x18\x03 \x01(\x05\x12\x0c\n\x04rain\x18\x04 \x01(\x05\x12\x0b\n\x03sea\x18\x05 \x01(\x05\x12\r\n\x05range\x18\x06 \x01(\x05\x12\x12\n\nscan_speed\x18\x07 \x01(\x05\x12\x33\n\x06spokes\x18\x08 \x01(\x0b\x32\x1e.magothy.protobuf.radar.SpokesH\x00\x88\x01\x01\x12/\n\x04pose\x18\n \x01(\x0b\x32\x1c.magothy.protobuf.radar.PoseH\x01\x88\x01\x01\x42\t\n\x07_spokesB\x07\n\x05_pose\"N\n\x07\x43ommand\x12\x34\n\x07\x63ommand\x18\x01 \x01(\x0e\x32#.magothy.protobuf.radar.CommandType\x12\r\n\x05value\x18\x02 \x01(\x03*\xc1\x01\n\x05State\x12\r\n\tSTATE_OFF\x10\x00\x12\x11\n\rSTATE_STANDBY\x10\x01\x12\x14\n\x10STATE_WARMING_UP\x10\x02\x12\x14\n\x10STATE_TIMED_IDLE\x10\x03\x12\x12\n\x0eSTATE_STOPPING\x10\x04\x12\x17\n\x13STATE_SPINNING_DOWN\x10\x05\x12\x12\n\x0eSTATE_STARTING\x10\x06\x12\x15\n\x11STATE_SPINNING_UP\x10\x07\x12\x12\n\x0eSTATE_TRANSMIT\x10\x08*w\n\x0b\x43ommandType\x12\x10\n\x0c\x43OMMAND_NONE\x10\x00\x12\x13\n\x0f\x43OMMAND_TURN_ON\x10\x01\x12\x14\n\x10\x43OMMAND_TURN_OFF\x10\x02\x12\x15\n\x11\x43OMMAND_SET_RANGE\x10\x03\x12\x14\n\x10\x43OMMAND_SET_GAIN\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'radar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STATE']._serialized_start=629
  _globals['_STATE']._serialized_end=822
  _globals['_COMMANDTYPE']._serialized_start=824
  _globals['_COMMANDTYPE']._serialized_end=943
  _globals['_POSE']._serialized_start=72
  _globals['_POSE']._serialized_end=133
  _globals['_SPOKES']._serialized_start=135
  _globals['_SPOKES']._serialized_end=222
  _globals['_INFO']._serialized_start=225
  _globals['_INFO']._serialized_end=546
  _globals['_COMMAND']._serialized_start=548
  _globals['_COMMAND']._serialized_end=626
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Color(_message.Message):
    __slots__ = ("red", "green", "blue", "alpha")
    RED_FIELD_NUMBER: _ClassVar[int]
    GREEN_FIELD_NUMBER: _ClassVar[int]
    BLUE_FIELD_NUMBER: _ClassVar[int]
    ALPHA_FIELD_NUMBER: _ClassVar[int]
    red: float
    green: float
    blue: float
    alpha: _wrappers_pb2.FloatValue
    def __init__(self, red: _Optional[float] = ..., green: _Optional[float] = ..., blue: _Optional[float] = ..., alpha: _Optional[_Union[_wrappers_pb2.FloatValue, _Mapping]] = ...) -> None: ...

class FramePrediction(_message.Message):
    __slots__ = ("x", "y", "width", "height", "confidence", "class_id", "class_name", "class_color")
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
    CLASS_COLOR_FIELD_NUMBER: _ClassVar[int]
    x: float
    y: float
    width: float
    height: float
    confidence: float
    class_id: int
    class_name: str
    class_color: Color
    def __init__(self, x: _Optional[float] = ..., y: _Optional[float] = ..., width: _Optional[float] = ..., height: _Optional[float] = ..., confidence: _Optional[float] = ..., class_id: _Optional[int] = ..., class_name: _Optional[str] = ..., class_color: _Optional[_Union[Color, _Mapping]] = ...) -> None: ...

class Frame(_message.Message):
    __slots__ = ("frame_number", "ttag_system", "ttag_steady_ns", "prediction_duration_ms", "predictions")
    FRAME_NUMBER_FIELD_NUMBER: _ClassVar[int]
    TTAG_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    PREDICTION_DURATION_MS_FIELD_NUMBER: _ClassVar[int]
    PREDICTIONS_FIELD_NUMBER: _ClassVar[int]
    frame_number: int
    ttag_system: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    prediction_duration_ms: int
    predictions: _containers.RepeatedCompositeFieldContainer[FramePrediction]
    def __init__(self, frame_number: _Optional[int] = ..., ttag_system: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., prediction_duration_ms: _Optional[int] = ..., predictions: _Optional[_Iterable[_Union[FramePrediction, _Mapping]]] = ...) -> None: ...

class OccupancyMap(_message.Message):
    __slots__ = ("ttag_system", "ttag_steady_ns", "type", "lat_deg", "lon_deg", "width_m", "height_m", "width_px", "height_px", "grid")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[OccupancyMap.Type]
        EMPTY: _ClassVar[OccupancyMap.Type]
        OCCUPIED: _ClassVar[OccupancyMap.Type]
        MERGED: _ClassVar[OccupancyMap.Type]
    UNKNOWN: OccupancyMap.Type
    EMPTY: OccupancyMap.Type
    OCCUPIED: OccupancyMap.Type
    MERGED: OccupancyMap.Type
    TTAG_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TTAG_STEADY_NS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    LAT_DEG_FIELD_NUMBER: _ClassVar[int]
    LON_DEG_FIELD_NUMBER: _ClassVar[int]
    WIDTH_M_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_M_FIELD_NUMBER: _ClassVar[int]
    WIDTH_PX_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_PX_FIELD_NUMBER: _ClassVar[int]
    GRID_FIELD_NUMBER: _ClassVar[int]
    ttag_system: _timestamp_pb2.Timestamp
    ttag_steady_ns: int
    type: OccupancyMap.Type
    lat_deg: float
    lon_deg: float
    width_m: float
    height_m: float
    width_px: int
    height_px: int
    grid: bytes
    def __init__(self, ttag_system: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ttag_steady_ns: _Optional[int] = ..., type: _Optional[_Union[OccupancyMap.Type, str]] = ..., lat_deg: _Optional[float] = ..., lon_deg: _Optional[float] = ..., width_m: _Optional[float] = ..., height_m: _Optional[float] = ..., width_px: _Optional[int] = ..., height_px: _Optional[int] = ..., grid: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csensor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf2\x01\n\x05Range\x12/\n\x0bttag_system\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0ettag_steady_ns\x18\x02 \x01(\x04\x12\x19\n\x04type\x18\x03 \x01(\x0e\x32\x0b.Range.Type\x12\x0f\n\x07range_m\x18\x04 \x01(\x01\x12\x1b\n\x13range_uncertainty_m\x18\x05 \x01(\x01\x12\x19\n\x11\x66ield_of_view_deg\x18\x06 \x01(\x01\"<\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nULTRASOUND\x10\x01\x12\x0c\n\x08INFRARED\x10\x02\x12\t\n\x05LASER\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sensor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RANGE']._serialized_start=50
  _globals['_RANGE']._serialized_end=292
  _globals['_RANGE_TYPE']._serialized_start=232
  _globals['_RANGE_TYPE']._serialized_end=292
# @@protoc_insertion_point(module_scope)
